@@ -228,6 +228,19 @@ class TestCompares:
         assert not ForCompare(f1=1, f2=2, f3=2) >= 0xA2
 
 
+class TestCompareValueError:
+
+    """Test when other can not be converted to an int."""
+
+    # pylint: disable=unneeded-not
+
+    def test_eq(self):
+        assert not ForCompare(f1=2, f2=2, f3=2) == "not valid"
+
+    def test_ne(self):
+        assert ForCompare(f1=2, f2=2, f3=2) != "not valid"
+
+
 class SimpleBits(BitFields, nbytes=1):
 
     """Sample BitFields subclass."""
