@@ -106,6 +106,9 @@ class TestFmtArg(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
@@ -154,9 +157,15 @@ class TestFmtArg(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -267,6 +276,9 @@ class TestMethod(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
@@ -320,9 +332,15 @@ class TestMethod(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
@@ -434,6 +452,9 @@ class TestProperty(Case):
 
             @classmethod
             def __pack__(cls, value, pieces: List[bytes], dump: Optional[Record] = None) -> None:
+                if isinstance(value, dict):
+                    value = cls._make_structure_from_dict(value)
+
                 (m_datatype, m_data, m_bookend) = value
 
                 if dump is None:
@@ -487,9 +508,15 @@ class TestProperty(Case):
 
                 return structure, offset
 
-            __eq__ = list.__eq__
+            def __eq__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__eq__(self, other)
 
-            __ne__ = list.__ne__
+            def __ne__(self, other: Any) -> bool:
+                if isinstance(other, dict):
+                    other = self._make_structure_from_dict(other)
+                return list.__ne__(self, other)
 
             def __repr__(self) -> str:
                 try:
